Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

16x04 - A Leap of Innovation!

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

16x04 - A Leap of Innovation!

Post by bunniefuu »

HEIDI:
Previously on Project Runway...

TIM: This is your
first unconventional

materials challenge.

It's also your first
team challenge.

DESIGNERS:
Oh.

TIM:
You will be transforming

the recycled goods

into a five-look
mini collection.

Ow! Ooh.

SHAWN [crying]:
I'm terrified of the shame

of failing.

Are these five looks coming out
of the same closet?

♪ ♪

HEIDI:
The winning team is...

Ballin' on a Budget.

Ayana, you are the winner
of this challenge.

♪ ♪

The losing team is

Tsunami.

Sentell,

I'm sorry,
that means you're out.

♪ ♪

-[car horn honks]
-♪ ♪

-HEIDI: Come on, Tim.
-TIM: What?

Shake it out a little bit.
Let me see you move those hips.

Shake your little booty.
Yeah, yeah, yeah, yeah, yeah.

-Arms in the air. Whoo!
-I'm getting dancing lessons

from Heidi Klum.

BOTH:
Whoo!

We got to go. It's time.

-I'm just loosening up.
-Okay, here we go.

-Uh-oh.
-[chuckling]

[all laughing]

HEIDI:
Oh, sh**t.

[laughing continues]

KUDZANAI:
Are we gonna go salsa dancing?

I don't know what's going on.

Hello, designers.

-Hello.
-Hey.

TIM:
We have been brushing up

-on our dance skills.
-DESIGNERS: Yeah.

TIM: And, in fact, Heidi
invented a new dance backstage.

AARON:
Yes.

[designers cheering
and laughing]

MARGARITA:
What do we call it?

I call it "Make it twerk."

-[Tim laughs]
-Okay. -Yeah.

And, designers,
for this challenge,

you're going to need
to make it work.

-All right.
-Okay.

TIM: And, in order to prepare
for the challenge,

we'd like you to look at a clip

from the new animated film Leap!

-Have a look.
-DESIGNERS: Okay.

FÉLICIE [on TV]: Since I can
remember, I've wanted to dance.

VICTOR [on TV]:
You? A dancer at the ballet?

You wouldn't last more
than five minutes

-out there. [grunts]
-[bell clings]

-Are you sure about that?
-AMY: It looks really cool.

Love to see little redhead girls

trying to go far
with their dreams.

FÉLICIE:
Do you have a plan?

VICTOR:
A brilliant plan.

[springing]

I call them chicken wings!

[designers chuckle]

♪ I wanna cut to the feeling ♪

FÉLICIE'S MOTHER:
No matter what happens,

-never give up on your dreams.
-♪ Oh, yeah ♪

It's kind of similar
to this experience right now.

-You can do it.
-[ding]

AARON: You have to go for it
and not let anything

get in your way.

♪ Cut to the feeling. ♪

-[applause]
-Yeah. -Cute.

TIM:
In the spirit of Leap!,

we want your next invention

to be a fashionable look

inspired by dance,

movement, and innovation.

MARGARITA:
Innovation? Kind of tricky,

but I think it could be
really fun. I'm excited.

HEIDI:
Get creative. Get inventive.

TIM:
For this challenge,

you will have one day.

You will have 30 minutes

to sketch here at the runway.

And then we're going
shopping at Mood,

where you'll have a budget
of $200.

HEIDI:
Now, me, personally, Tim,

I like to hip-hop dance.

[laughter]

And I enjoy the ballet.

So, before you begin sketching,

we want to introduce you

to some incredibly
innovative dancers.

They have combined
hip-hop and ballet

to give you
a little inspiration.

-[designers murmur]
-And they are called

Hiplet.

[classical music plays]

KENYA:
It is the most beautiful

thing I've ever seen.

[hip-hop music plays]

-Oh, my God.
-Yes!

[chuckles]

Yeah.

Oh, hey.

It's, it's... wow.

-Whoo!
-Oh, my God, this is so good.

[song ends]

-[cheering and applause]
-AARON: Yay!

What inspiration.

-ALL: Yeah.
-Yes. Totally.

TIM: All right.
You've been assigned new models.

And your 30 minutes
of sketching begins...

right now!

-Nice.
-Hell yeah.

-♪ ♪
-[softly]: Let's see.

DEYONTÉ: The Hiplet girls,
they looked amazing

and very innovative, so

I'd want to showcase
the movability of a garment.

I won the first challenge

and I'm ready to
take this win as well.

TIM: All right, designers,
your sketching time is up.

And we're heading off to Mood.

-♪ ♪
-[car horn honks]

Okay, your 30 minutes
begins now.

[designers clamoring]

MARGARITA:
The movie Leap! made me think,

"Okay, what am I
passionate about?"

I'm passionate
where I come from,

my family, my culture.

So I am designing

a bomba-inspired outfit.

Bomba is a Puerto Rican dance.

Let's do, um... ten, please.

Do you have similar,
like less texture?

Might be a lot of sparkle.
But I don't mind.

My idea is to create a look

that is flowy and has movement,

but also looks like stars
and looks like midnight.

'Cause the whole idea is that,

you know, reach for the stars.

-I'll take it. Yes.
-Yeah?

Yes, I'll make it work.

TIM: Designers, you have
one minute remaining.

You have one minute
left to shop.

Thank you, beautiful.

-Thank you.
-Pleasure.

TIM:
All right. Time is up.

No more shopping.

Thank you very much.

-TIM: Thank you, Mood.
-DESIGNERS : Thank you, Mood.

♪ ♪

Phew.

SAMANTHA:
Okay.

-BRANDON: Oh ,that's a nice
fabric. -KENYA: Thank you.

I'm gonna utilize both sides.

-DEYONTÉ: I love that.
-I'm very much inspired

by fabric, so fabric kind of
jumps out and says, "Okay..."

-It's got to start talking.
-Right.

"This is what I want you
to do with me.

-Take me home." [laughs]
-Yeah.

Come here, girlfriend.

MARGARITA:
Kentaro, what's your favorite

piano piece to play?

KENTARO:
Probably Tchaikovsky.

Very much, I was inspired by
all the classical music.

Before I got into fashion,

I was a classical pianist.

[piano playing]

♪ ♪

KUDZANAI: I really want to do
something that

gets the judges' attention.

I'm African, so

I'm incorporating a lot
of different aspects from

African cultures.

Feathers, the colors,
all those elements

of motion and movement.

You good, Brandon?

BRANDON:
Oh, I'm good, bro.

I'm really just
kind of focused on detail

with a more minimal cut.

AARON:
Brandon, what are you making?

BRANDON: You'll just have
to wait and see, buddy.

All right. Let's see it, then.

BRANDON:
I can get kind of intense.

Focus, really calm,
just kind of taking my time.

♪ ♪

Do any of you guys
actually dance?

-Yeah.
-You do?

Like, what kind of dance
do you do, Batani?

BATANI:
Hip-hop, I do belly dance.

-Belly dance?
-Yeah.

AARON:
Wait, can you give us a taste?

Can you do,
like, a little, like...?

-[giggles] -Batani, you have,
like, a secret talent.

-♪ Da, da-da-da-da, da-da-da ♪
-[laughs]

♪ Da, da-da-da-da, da-da-da ♪

-Yeah!
-♪ Da, da-da-da-da-da, da-da ♪

♪ Da, da-da-da-da, da-da-da ♪

-♪ Ah! ♪
-Yeah!

-♪ Ah! Ah! ♪
-[giggles]

[all cheer and applaud]

-That's awesome.
-I love it. That was so good.

DEYONTÉ: My fabrics
are chartreuse green.

It's loud, it's almost a neon.

It's coming together
really easy

and usually,
that's a good sign

that it's gonna be
a good garment.

[sewing machine whirring]

Oh, you can lift the foot on it.

-Lift the foot.
-Oh, I thought it was lifted.

-[machine clunks]
-Aah! Aah!

-Needle in my... -Oh,
take it out, take it-- oh, God.

-Are you okay?
-No.

Oh, [bleep], the needle goes

right directly
through my finger.

-Aah, aah!
-Oh.

HEIDI:
Coming up on Project Runway...

-[yelps]
-CLAIRE: Shawny!

Hey. Don't you love that?

Remarkable.

Chic and cool.

These are the moments
I wait for.

It was absolutely stunning.

[laughs]:
What is that?

-Lift the foot.
-Oh, I thought it was lifted.

-[machine clunks]
-Aah! Aah!

-Needle in my... -Oh,
take it out, take it-- oh, God.

It's literally stuck in there.

Straight through.

-You okay?
-No.

-Aah!
-KENYA: Your finger?

Went all the way through.

KENYA:
Oh, God.

I have [bleep] up my finger.

I don't want to complain,

but I'm just, like,
kind of in shock.

It's my bad. I'm good.

Probably.

The medics run up,
it's a little bit of chaos.

CLAIRE: Deyonté just sewed
through his finger.

-AMY: Oh, my God.
-Oh, God.

-AARON: He sewed through
his finger? -CLAIRE: Yeah.

-He got it stuck.
-AARON: Holy [bleep]. Ugh.

-Oh, God.
-AARON: Ooh, damn.

It went all the way
through my finger.

-KENYA: Oh!
-Yeah.

DEYONTÉ: The medics
patch my finger up,

so I get back to work.

I'm just a little bit nervous

on how I'm gonna
get my finishes done.

♪ ♪

MARGARITA:
This week's challenge is

to create a fashionable look
based on dance...

Ta-da!

...movement and innovation,

inspired by the movie Leap!

My look is this
wraparound jumpsuit.

It's got this
one-shouldered sleeve.

And I want to, like, highlight
the spread of the body.

Like, if you can do it.

It's kind of a weird design.

And I-I love it.

SHAWN:
The first thing I do

is start dyeing
my two top fabrics

that I'm gonna turn into
a crossover cropped hoodie top

and a pair
of silk cargo joggers.

[yelps]

No big.

I'm just tired
of the twins running around

the workroom like
their heads are cut off.

[whoops]
Lady on a mission.

They...

Running around
like they've lost it.

Whoops.

The twins are a lot.

Guys, be careful
in the overflow room.

I have fabric out.

KUDZANAI:
It's like, you can't

have a peaceful quiet moment

because they're like, "Shawny!"

And, "Hey, Claire!"

SHAWN: Hey, Claire,
can I have your opinion?

-Pumpkin pie.
-Yes, boo boo.

Shawny, can you come
look at this?

Yes.

Coming.

KUDZANAI:
Project Runway, please,

stop sitting me
next to the twins.

♪ ♪

Hi.

ALL:
Hi.

How is everyone?

-Very well, thank you.
-TIM: Great.

How are you?

I sewed my finger today,
so I'm moving a little slow.

-Oh, no.
-But I'm making it work.

-It's a "make it work" moment.
-Did medics see you?

-Yes.
-Okay, good. Talk to me.

First of all,
I loved the movie Leap!

It was very inspiring.

About the underdog taking a risk
and a leap of faith.

So, I wanted to give her a gown

'cause she's probably gonna be
going to a ball.

So I'm gonna do something fun

and it's gonna have
a really dramatic neckline.

-Okay. -And a little pop of
ruffles coming out, possibly.

I'm having a lot of trouble.
I'd keep it clean.

Just keep it clean?
I agree.

It's doing too much.

I'm actually working on, like,
a shirt dress.

I wanted it to kind of be, like,
really minimal kind of cuts.

But something that has, like,
a lot of detailing.

TIM: This would have a relevance
as much in the 15th century

as it would in 2500.

In this form, it's stunning.

My client just called,
she said, "Hey, Kenya,

"I'm going to
the hip-hop ballet,

and we're having c*ck
after. What you got for me?"

I think it's smashing.

-Go, go, go, go, go, go.
-[laughs] Thank you, Tim.

-Smashing.
-I really like rock operas.

-Mm-hmm. -And I like the idea
of a metal ballet.

-Hmm. -Kind of witchy,
kind of ballet.

I don't want it to be burlesque.

-Quite magnificent.
-Thank you.

So I wanted to start with,
like, a kimono.

I stuck with
kind of like a geisha

getting transported
into this generation

and falling in love
with voguing.

-And then, once it's revealed...
-Good heavens.

...it's kind of a folded play

and kind of
a Japanese technique.

-I have to tell you, I think
it's fabulous. -Thank you.

My initial idea was
to do a very full pant,

has lots of movement,
you know, it'll...

do its thing on the runway,

and I wasn't sure if part of
the garment should change or...

-You're thinking too hard.
-Okay.

-Execute this.
-Okay, good.

-Just carry on.
-Great.

And stay away from Red Bull
and coffee.

I wanted to, like, highlight

the specific areas
that would, like...

do that when you reach out.

So, basically, it's gonna be,
like, a wrap, like, jumpsuit.

TIM: I don't want this
to end up being

a garment that's a pu-pu platter
of different treatments.

I just don't want it
to get too gimmicky.

This piece is her
sweater/sweaterdress.

In the multipurpose universe,

this is now gonna
become a jumpsuit.

So, she takes this off

and she's gonna step
back into it.

-Oh, there's another armhole.
-Yeah.

So the sleeves of the sweater
become the legs

of the jumpsuit.

Remarkable.

My vision was blending hip-hop
with ballet.

Imagine it as
a sweatpants silhouette.

Ask yourself,
"Am I being too literal?"

And I was wondering that. Yes.

-What are you doing?
-Pleating.

Excellent.

How are you using the pleating?

So, maybe I'm going to have
a little bit of circle skirt

up to here, then I'm gonna
attach the pleat,

-so it flares.
-So it will...

-Moves.
-Okay.

Well, see where it goes.

Thank you, Tim.

Good heavens, Batani.

I thought about movement.

I thought about things that fly,
like butterflies and birds.

So I decided to create this
butterfly cape in the back

for when the model
walks down the runway.

-It's fantastic.
-And it's flowing behind her.

-[laughs]
-I'm inspired.

I feel as though
I can't wait to see it,

-because I can't.
-Cool.

MARGARITA:
I picked something

that kind of resonates
with my culture.

The bomba dancing
is very passionate dance.

It's very Puerto Rican.

And it's usually white cotton

with, like, some red trim.

So I'm kind of playing on that.

I mean, quite frankly,

there's so much happening here,

this looks full tilt costume.

MARGARITA:
I look at the garment

and I'm just thinking,

"What am I gonna do?"

HEIDI:
Coming up on Project Runway...

♪ ♪

Doggone it.

I'm in so much freaking pain.

MARGARITA: This is my worst
nightmare. I want to win.

TIM:
I mean, quite frankly,

there's so much happening here,

this looks full tilt costume.

-Don't try too hard. Okay?
-Okay.

Duh, of course I'm trying
too hard. I want to win.

Like, what are you
talking about?

Of course I'm trying hard.
Really hard.

You need to keep your eye on it.

And keep it out of costume land.

Yeah. Okay.

TIM:
What's this print?

-So, it's stars that I painted.
-Oh, you painted it?

-And then-- mm-hmm.
-Oh. I love it.

AYANA:
On top of this is going to be

layers, so the stars just kind
of shine through

and then it shows
some dimension.

It just--
there's a lot going on.

-I would reel it in a bit.
-Okay.

Uh, I initially just thought
about, you know,

some of the cultures that
I've been raised around.

So I took the idea
of the urban hoodie.

-Oh. -So it's going
to drape in here.

And I'm infusing the African
part of the culture

is, uh, putting, like,
dashiki print on it.

I'm gonna cut
strips of the fabric

so that it kind of goes
all the way around like that.

TIM: And where
are the feathers going?

Feathers are gonna be
on the back of it, actually.

I want that element of surprise,
so when she's walking,

-the feathers will be going down
the back of her sleeves. -Okay.

-Does it seem like a lot?
-Yes.

If any of the judges are nodding
off, this will wake them up.

-Well, I hope so.
-[chuckles]

TIM:
Designers, if you're

in the Brother sewing
and embroidery studio,

would you please come in
just for a minute?

You all are incredible

and you're being
extraordinarily ambitious.

You are stepping up and out.

You're taking risks.

I couldn't be happier.

I want you to know that.

[applause]

TIM:
All right, your models

will be coming in in an hour
and 15 minutes.

-Whoo!
-All right?

You will have until 9:30
tonight here.

-Okay.
-And I will

see you in the morning.

-Thank you, Tim.
-Bye, Tim.

♪ ♪

There's a third component
to this challenge

other than dance and movement.
It's innovation.

And I'm like, how am
I gonna be innovative?

So, I was like,

what if I turn the top

from the front to the back?

You know, it's gonna be a
little revealing in the stomach

because, unfortunately,
it was designed for the back,

but who doesn't want
to see a little skin?

Great chat.

Thanks.

-Hi.
-Hey.

-Samantha, I'm Shawn.
-Give me a hug.

Batani. Nice to meet you.

-Hey. Mwah.
-I'm so excited.

Just seeing it on you
makes me feel very relieved.

-Yeah?
-Mm-hmm.

Oh, I am awesome.

Kind of do a wave with your arms
like a "S". "S."

It was supposed to be
the front in the back

and the back in the front.

So, slip in there carefully.

There's pins.

I want you to get steamed.

BRANDON:
Very cute.

MARSHA:
I was so happy

to find out that Brandon
is my designer, actually.

All the girls are kind of like
in love with him,

[laughing]:
so...

AARON:
I always have fit issues.

For the love of [bleep].

My torso is longer than

the bodysuit
he designed for me.

It's not comfortable yet.

All right, beautiful.
Let's get this together.

MONIQUE: I know the skirt
is very fitted right now,

so hopefully I can walk in it.

-Bye!
-Bye!

KUDZANAI:
I was going to origami these

dashiki prints on the neon,

but I don't know that I'm gonna
have enough time to do that.

I definitely bit off

a little bit more
than I can chew.

Like, yeah.

♪ ♪

Okay.

BATANI:
Hurry and pin.

Pin and hurry.

Hurry and pin.
Pin and hurry.

AMY:
Ah, I hate late-night sewing.

It's so stressful.

♪ I hate making this
[bleep] armhole. ♪

Sanita said that her torso
is too long.

So, I am repatterning

the whole jumpsuit
so I can make it bigger,

and I'm stressing out.

SAMANTHA: Aaron seems
a little bit concerned

about his look.
He's worried that

the proportions
are going to be wrong.

I'm such a freaking mess.

I think he might be in trouble.

But you know what?
I'm here to [bleep] it up.

CLAIRE:
Is your finger okay?

DEYONTÉ:
I mean, I would love to have

more use of it right now,
especially doing these.

I'm having a hard time

trying to complete my garment.

[sighs]

I have a lot of work to do.

I am having
a true "make it work" moment.

Doggone it.

HEIDI:
Coming up on Project Runway...

-Aah!
-TIM: Designers and models,

we're headed down to the runway.

-Aah!
-Oh, no.

-MONIQUE: My hair came off!
-Geez, oh, my God.

TIM:
Off we go.

♪ ♪

KUDZANAI: ♪ Let's get it done,
done, done, done. ♪

Let the door slam on me
like a jerk.

-Terrible. -I thought you
were right behind me.

SAMANTHA:
I wasn't.

SHAWN: Okay, I'm using these
tweezers apparently.

Damn it!

Aah! Stabbed myself.

What the fecal matter?

But I am spazzing over here.

I've still got zippers
to put on.

I've still got
to attach these feathers.

There's just so much
that I have to do

in this little bit of time.

I cannot stop sweating.

-Good morning, everyone.
-[designers greet Tim]

TIM:
What a quiet room.

Yes, indeed.

Is there a lot of work
yet to do?

-Yeah. -Yes.
-TIM: Okay.

Well, you'll have a little bit
of time with your models.

Two hours to send them
to the Avon Beauty Lab

and to our hair studio.

There is a lot of exuberance
in this room,

so use the JCPenney
accessory wall thoughtfully.

All right?

-Thank you. -TIM: All right?
I'll see you a little later.

-SHAWN: Thank you so much, Tim.
-TIM: Thank you.

KENYA:
Thank you, Tim.

♪ ♪

[whistle]

-Hi. -AARON: Girls.
-MARGARITA: Lena!

AARON: I still have a lot of
sewing I need to get doing,

so... [groans]

SHAWN: I swear, no matter how
prepared you think you are,

it is always a hustle.

♪ ♪

-This is Jazzmine.
-Hey, Jazzmine.

CLAIRE: I'm looking
for a bright fuchsia lip

and then a slight cat eye.

HECTOR: So, let's do
with the gel pencil.

CLAIRE:
Yeah.

I wanted her eyes like pinkish,
smoky eye.

And I want
like a berry-colored lip.

You know, a dark berry.

Yeah, I like it.

-I'm super excited.
-Yes.

MICHAEL:
What I want to do is do

a really graphic line of gold.

HECTOR: So, we have
the perfect gold for that.

MICHAEL:
Yes.

I love it.

-[tinkling]
-Aah, sorry.

♪ ♪

This a $25 zipper.

This mother-sucker better work.

MARGARITA:
I still have not attached

a ruffle to my skirt.

-Starting from here?
-Mm-hmm.

He's like,
"Do you want me to help?"

And I was like,
"Yes! Grab a needle!

Help me attach these, please!"

PRODUCER:
Innovation.

TIM: Designers, in ten minutes,
you and your models and I

are going down to the runway.
All right?

-Okay.
-All right.

[bleep], [bleep], [bleep],
[bleep] got real.

♪ ♪

BRANDON:
Ten?

MARSHA: I'm a size nine,
but I can do a ten.

SHAWN:
I love Brandon's.

I think it's very architectural
and I'm jealous.

BRANDON: Oh, I love it.
[chuckles]

CLAIRE:
I'm sorry.

I don't care
for Brandon's look.

It's just so stiff.

Stretch it out a little bit.
Stretch it out.

We'll get it on.

I don't have time
to put on closures,

so I'm like, oh, yeah,
this is stretch cotton,

so it's gonna look good

because it's gonna be
really fitted.

-It's working, it's working,
it's working. -Aah!

-Almost there. Oh, no.
-[laughs]

My hair came off!

KUDZANAI: And, yeah, that's when
my life was, like...

[groans lightly]

♪ ♪

MARGARITA:
I'll fix it. Don't worry.

I'll move you.

You stand there, look pretty.

She has clothes on,

so, thank you, Jesus.

[humming]

I know, it actually
doesn't suck.

I'm wildly surprised.

SANITA: Aaron, he changed
the fit for my torso,

so it really fits me.

I really, really like it.

Designers and models,
we're headed down to the runway

-for a fabulous show.
-[cheers, applause]

I got to cut this bottom.

LIRIS: Technically, I think
he had great ideas.

He didn't have enough time
to execute everything,

but I'm gonna pull it off
and work it on the runway.

TIM:
Off we go.

HEIDI:
Coming up on Project Runway...

-Wow.
-It's absolutely beautiful.

-It is fabulous.
-It made me want to dance.

Ooh. This is supposed
to be fashion.

It's too, too, too much.

-Okay.
-ZAC: Surprise.

[groans]

-Hello.
-Hello. -Hi.

Welcome to the runway.
As you know, in fashion,

one day you're in,
and the next day you're out.

This season on Project Runway,
you will be working

with models of all sizes.

After all, one size
does not fit all.

For this challenge, we asked
that you to create a look

inspired by dance, movement
and innovation.

Ayana, since you won
the last challenge,

you have immunity today
and cannot be eliminated.

-Thank you.
-Doesn't that feel good?

All right, let's say hello
to our judges.

First, we have director
for Brooks Brothers Women

and fashion designer, Zac Posen.

-Hi, designers.
-Hi, Zac.

ALL:
Hi.

Creative director for
Marie Claire magazine,

-Nina Garcia.
-Hi, Nina.

Hi, everyone.

And our special guest judge
for today,

dancer, New York Times
best-selling author,

fashion designer and actress--

starring in the animated film
Leap!-- Maddie Ziegler.

-Hi, guys.
-ALL: Hi.

Also, we love having Tim Gunn
here for the runway show.

He is your mentor and will not
be judging your looks.

All right, let's start the show.

♪ ♪

KENYA:
I feel so good about my look.

The jacket is amazing,
the collar is just nice.

I can see my trim and all
the work that I put in,

and the button details.

The jumpsuit fits
that body so nice.

I'm like, "I want to buy it."
[laughs]

♪ ♪

BRANDON:
Marsha's just k*lling it.

It's everything
that I wanted to convey.

I absolutely love what I did.

There's something fresh
about it.

It's very relevant,
it's very now.

♪ ♪

MICHAEL: Watching my look
come down the runway,

it's perfect.

I'm really hoping that
the judges are

paying close attention
to my technique.

It's a huge part of my design
to manipulate my textiles.

♪ ♪

♪ ♪

MARGARITA: She looks
so chic, it's crisp white.

And she looks like she's ready
to go to Havana

or somewhere,
just dance the night away.

I'm feeling pretty good about
it, I think it came together.

I'm so excited.

♪ ♪

♪ ♪

DEYONTÉ:
She is floating,

the fabric is moving.

I feel like the color is
really electric.

It's telling a great story.

I can see she's confident.
I feel really good.

♪ ♪

AMY: Watching my look
come down the runway,

I am so excited--
I feel like a little kid.

I think I have really nailed
this garment idea.

It looks cool.

♪ ♪

KUDZANAI:
I like the colors.

I like the direction
at the top.

I like how dramatic it is
and how, like,

it looks so oversize.

And then I love how slim
the skirt fits her.

I actually like
the feathers on the skirt.

I think
it's a very cool element.

I think she looks good in it.

CLAIRE:
Jazzmine is really working it,

making it flow.

I love the layers
of the colors,

as well as the ties
that I've added

that are kind of fluttering
behind her

as she's moving.

She's like a vision in red.

♪ ♪

AYANA:
Yeah!

I am so proud of it.

Sian is making me look
so good.

It just helped me achieve
what I was trying to achieve.

And I'm so, so happy with it.

I wouldn't change anything.

SHAWN: I love the movement
that this outfit provides.

I can definitely see
the dance inspiration.

The sash moves.

The silk pants have
an ease to them.

She feels comfortable,
she feels effortless.

That is very, very exciting.

♪ ♪

AARON: I was really inspired
by just, like,

a movement in dance, and just,
like, how the body is moving.

It's got some, like, cool,
weird elements going on.

It kind of looks crazy,
but it's really fun, you know?

I'm-I'm super excited
about my look.

♪ ♪

BATANI: She's bouncing
down the runway,

and the cape's just
flowing behind her,

and everything's just
looking beautiful.

It's looking just like
a butterfly,

just like I had
planned it to look.

It's everything I envisioned,

so I'm very, very happy
about this,

so I think I'll be in the top.

♪ ♪

KENTARO:
I think, like, it's functional

and it looks beautiful,
flowing nicely, and, yeah,

I'm happy with everything
what I have done.

I feel very confident
and, yeah,

I think I'm gonna be okay.

♪ ♪

SAMANTHA: I asked her to do
a prim and proper

model walk and then
do the reveal.

So she can just rock it out.

And she looks badass.

It looks super tough.

Everything about it is perfect.

HEIDI:
Designers, I have to say

that was a fabulous
runway show today.

-Thank you. -Thank you.
-Thank you.

HEIDI:
If I call your name,

please step forward.

Kentaro.

Deyonté. Kudzanai.

Margarita, please step forward.

Batani.

Brandon.

If I have not called your name,
congratulations.

Your scores have qualified you
to move onto the next round.

You can leave the runway.

Thank you.

The six of you have the highest
and the lowest scores.

One of you will be named
the winner

and one of you will be out.

Batani, tell us about your look

and your inspiration.

From the movie, Leap!,

I took inspiration
from the inventor.

He was flying.
He had wings.

And so I thought
about colorful butterflies.

When I first saw the shadow

of this, I already liked it.

And then when it walked

down the runway,

the print, the color,

the fluidity of the fabric
really captured it for me.

I could see exactly
where you were going

with the whole inventor, Victor,
who is the character. -Yeah.

And I could really relate

to this as a dance piece because
it's very fashion-forward.

I think it's beautiful.

-I really love it.
-Thank you. Thank you.

-The effect of this worked.
-Thank you.

HEIDI:
You definitely showed us drama

-and something special today.
-Thank you.

Deyonté, tell us about
your inspiration and your look.

She is going out on the town
to see the Hiplet dancers

in Chicago,
so I wanted her to feel relaxed,

I wanted to show
a little bit of leg,

and I wanted her to feel
vibrant, sexy and free.

Well, it's definitely vibrant.

Thank you.

What do you think, Zac?

That's about it.

-[scoffs]
-HEIDI: That's it?

-Okay.
-It's dull.

A shirred skirt and a lace top
and a mullet hem?

[exhales]

MADDIE:
Actually, this reminded me most

of dance, only because
I've actually worn a costume

almost exactly like that,
and I did love the lace.

-Thank you. -You did say
the word "costume," though.

-Yeah.
-You guys are designers--

this is supposed to be fashion.

I see, like, an ice skater,
I see bad '80s.

Ooh.

-Does the ruff come off?
-Yes.

ZAC [exhales]:
Ah, breathing.

Marginally better. You won
the very first challenge,

and here we are,
three weeks into this,

and then you send this
down the runway--

it does make me question
your taste level.

-Kentaro.
-When I was watching movie,

it kind of reminds me of my...
training as a pianist.

Tchaikovsky's Swan Lake.

Like, purely ballet
and classic beauty.

So I made her like a black swan.

Yeah, I'm not impressed.

HEIDI:
Because of the leg warmers,

the tutu-inspired skirt,
it's a little bit too literal.

And it's just a little bit

black on black
on black on black.

Maybe, had you done this
in another color...

There needed to be some kind
of a punch when we saw it.

It just looks like

you didn't make
enough of an effort.

If I get a chance, next time I'm
gonna push myself a little more,

because I love colors.

You also have to step back.

-KENTARO: Mm-hmm.
-Look at the playing field.

Say, "What's gonna bring out
my subtleties?"

HEIDI: Thank you, Kentaro.
Margarita.

I was very inspired
with the challenge of dance,

and movement.
And bomba came to mind,

which is a very typical
Puerto Rican dance.

So I took a little inspiration
from that

and kind of set her
in a little tropical...

-paradise ensemble.
-I thought it was very nice.

And it looks like it just came
out of the store, too.

It looks very well-made.

Thank you.

I absolutely loved this look.

I thought it was
very refreshing.

It reminded me of kind of
a salsa feel on the bottom.

And I would love to wear this,
personally.

-Thank you.
-NINA: I love the sleeve.

I think there's
a lot of drama to it.

The sleeve is particularly
hard to construct.

And I think you did
a beautiful job.

I love the spirit of this dress.

-Thank you.
-Brandon.

Hip-hop was the inspiration.
I'm a big hip-hop head.

And also pop.

I kind of had,
like, Ariana Grande

or Rihanna in mind
when I was making it.

Wow. I love this.

-Thank you.
-I love

the creativity,

I love its boldness,

the styling was superb,

the makeup on the girl
was superb.

I love the fact that you layered

all these very unexpected
lengths, really.

It appeared on the runway,
and...

you just wanted to see more.

Thank you so much.

I love the color, too,

because it's an off-white,

and then here it's
another kind of cream color.

Very chic. Chic and cool.

It's absolutely stunning.

It's so modern and lyrical,
and I think

it's absolutely beautiful.

ZAC:
These are the moments I wait for

on Project Runway.

It's a really focused
point of view.

It talks about movement,
innovation,

you're playing with form,
with structure,

it still feels light,

the finishing is impeccable.

-And I want you to be able to
speak up for your work. -Okay.

I agree. I'm gonna work on it.

-Kudzanai. -I naturally
thought about my culture.

So I mixed a little bit of

West Indian culture,
the Carnival,

hence the bright colors,
the feathers.

And it's just vibrant,
and I just think about that

-when I think of Carnival.
-HEIDI: I feel like you got

a little too inspired by

a children's movie
because it looks very juvenile.

And it's also
not very flattering.

It kind of looks like a piñata

that exploded, too,

in the back.
Like, the skirt down there,

I just don't understand it.

Here, also, in her chest,

like, I don't know
what happened here.

Well, I took the idea of

a hip-hop hoodie
and put it in a different way.

For me, it was too bizarre.

If we put this outfit
next to Kentaro's,

it is exactly the flip.

Where Kentaro's is very minimal,

this is maximalist at the max.

Too many feathers,

too many colors, too many bands.

-MADDIE: Oh.
-Oh, there's more.

ZAC:
Surprise.

HEIDI [laughing]:
What is that?

You've embellished it so much

that it's just taking away.

It's too, too, too much.

HEIDI: We've heard
what you had to say.

We're going to take a closer
look at your designs,

have a little chat,

and then
I'm gonna bring you back.

Now you can leave the runway.

Thank you.

HEIDI: The winner of
Project Runway will receive

the opportunity to collaborate
with JCPenney

on a limited edition
capsule collection as part of

the Project Runway line sold

at select JCPenney stores;

a selection of Brother sewing
and embroidery machines,

with a retail value of $40,000;

makeup and beauty products
for a year, courtesy of Avon;

the new 2018 Lexus NX,
coming this fall

with advanced innovation
and safety system standard;

from the Pilot FriXion
Erasable Pen,

the official pen
of Project Runway,

a lifetime supply of pens;

an all-expense-paid luxury trip
to Japan,

including a five-star stay
near Japan's fashion center;

$100,000 to launch their line;

and the winning designer
and model will receive

a fashion spread
in Marie Claire magazine.

-TIM: Hi.
-Hi, Tim.

HEIDI: What an interesting
runway show today.

-I'm incredibly impressed
with this group. -Yes.

-ZAC: Me, too.
-They were really ambitious.

And they're feeling the heat
of the competition now.

-Yeah.
-They need to do more.

-Yeah. -So would you like to
start with Marsha,

-wearing Brandon?
-Oh, my goodness.

[clapping]
Yes, yes, yes, yes, yes.

-Fabulous.
-At first,

I didn't know if I was gonna,
like, love this,

-Mm-hmm. -but now that
I'm, like, looking at it,

-it's so beautiful.
-ZAC: I often think

that's what some great fashion
comes to.

MADDIE:
It's so simple, but it's...

-NINA: Powerful. -...at the
same time, so... Yeah.

NINA:
So simple, but so powerful.

♪ ♪

-TIM: Meisha, wearing Batani.
-HEIDI: Yes.

ZAC: I mean,
definitely runway effect.

It's really fun.
It would be so fun to dance in.

HEIDI: I can
totally see Batani in that.

I can see you in this, Heidi.

♪ Ta-da! ♪

TIM:
Lena is wearing Margarita.

-You just want to dance
in this dress. -Yeah. -Yeah.

-MADDIE: You do.
-ZAC: What was so great

was she looked at her garment
and she turned it around.

And that's the smart choices
that you make as a designer.

-TIM: Absolutely.
-MADDIE: I feel like it's, like,

a perfect, like, summer

-kind of dress.
-HEIDI: You want to

-go to Capri with this.
-Yeah. -Totally.

♪ ♪

-TIM: Liris is wearing Deyonté.
-HEIDI: Now, this

-is really painful.
-NINA: You see

-how short-waisted you look?
Do you notice that? -It...

-it could have been dropped
a bit. -HEIDI: It's too short.

-NINA: It's too short. -ZAC:
I'm taking it for what it is.

I'm worried about
basic construction.

-I mean... it's all pinned.
-[Heidi gasps]

-I don't understand this.
-TIM: But remember,

-he won the first challenge.
-I-I know that, that's why

we're surprised.

♪ ♪

Yordanos is wearing Kentaro.

HEIDI:
I mean, it is really well-made.

It really is.
I give him that.

But he sacrificed creativity.

-He was being too literal.
-HEIDI: Yes.

TIM:
Monique is wearing Kudzanai.

MADDIE:
Whoa.

-Yeah.
-NINA: No, the ribbons.

-This could be a kite.
-HEIDI: It's just everything.

-It could be a piñata.
-He put everything on there.

-Gosh. -Look,
there's zippers on the back.

-Why not? -ZAC: So we have
somebody with a lot of ideas.

NINA:
Just to point out--

the "a lot of ideas"
are all scary ideas.

HEIDI AND ZAC:
Thank you, Tim.

HEIDI:
Thank you, ladies.

-TIM: Thank you.
-HEIDI: Okay, so, we've made

our decision.

Let's bring them back out.

♪ ♪

HEIDI:
Designers, the six of you

had the highest
and the lowest scores.

One of you will be
named the winner...

and one of you will be out.

♪ ♪

Brandon, we can tell
that you have a lot of talent.

And we're also appreciative that
you showed us something so bold.

You leave us wanting more.

Thank you.

Congratulations! You are the
clear winner of this challenge.

Thank you so much.
Thank you, thank you.

I feel good, you know?
I feel recognized.

And also, I feel proud
of what I've put out thus far.

So I'm just hoping
that I can keep doing as such,

so thank you.

This also means that you have
immunity for the next challenge,

and you cannot get eliminated.

Awesome.
I like that.

You're in,
you can leave the runway.

Okay, thank you, guys.

My heart is beating so hard,
it... I'm just...

I'm so lost,
I'm struck for words.

And... I mean,
it just feels amazing.

And I'm excited
to get some rest

and, uh, do it all over again.

Batani, we knew
that this was your look

when it walked down the runway.

Margarita, your look
made us want to dance.

You're both in.
You can leave the runway.

Thank you, guys.

♪ ♪

Kentaro, your look
was impeccably made.

Unfortunately, there was
not enough imagination.

You have to step it up...

I will.

...next time.

You're in.
You can leave the runway.

-Thank you.
-♪ ♪

Deyonté...

the proportions were all wrong.

And the construction of your
garment was a real problem.

Kudzanai, from the colors
to the zippers

to the feathers to the ribbons,

you threw everything
into your design today.

And it just did not work.

Kudzanai...

...I'm sorry, you're out.

♪ ♪

Deyonté, that means you're in.

Barely.

You can leave the runway.

HEIDI:
I'm sorry, Kudzanai.

Thank you.

Auf Wiedersehen.
[kisses]

-Thank you.
-All the best to you.

All right. Thank you.

♪ ♪

KUDZANAI:
I don't take it personally.

I understand,
creatively, that we all

look at things differently
and we all work differently.

But I don't think
I did a terrible job.

I don't think
it was a terrible look.

♪ ♪

-Hey. -Oh...
-[slow exhale]

Well, it was a pleasure.

You're always
gonna be my brother.

Bye, brother.

DEYONTÉ:
Oh, my God.

It was a pleasure.

You take care of yourself, okay?

I will. Do the same.

I'm a fighter.
It's just one of those things.

You take one on the chin
and you keep it pushing.

Whether or not
we ever cross paths again,

Kudzanai's gonna be Kudzanai,

Kudzanai's gonna be a king,
and Kudzanai's gonna be great.

♪ ♪

HEIDI:
Next time on Project Runway...

You're sleeping on top
of the Empire State Building!

AARON:
It's, like, a crazy thing.

No one's ever done it before.

DEYONTÉ:
I'm on the top of the world!

-Whoo!
-Take, like, a five-minute...

-I don't have five minutes.
-Ooh.

I'm worried a bit.

They're looking at me like...
[chokes]

If we put a charcoal
up your rear end,

it would come out a diamond.

-[Heidi gasps]
-[ding]

There's some design here.

The entire look is beautiful.

The shape-- it's a problem.

It's, like, driving me crazy.

Show me,
what is sexy about this?

Thank goodness
you're wearing underpants.

HEIDI: Visit myLifetime.com
to learn more

about the fashion you've seen
on tonight's show.